embassy-time-queue-utils

Crates

git

Versions

default

Flavors

Queue

Struct Queue 

pub struct Queue { /* private fields */ }
A timer queue with a pre-determined capacity.

Implementations

Source

impl Queue

pub const fn new() -> Self

Creates a new timer queue.

pub fn schedule_wake(&mut self, at: u64, waker: &Waker) -> bool

Schedules a task to run at a specific time, and returns whether any changes were made.

If this function returns true, the caller should find the next expiration time and set a new alarm for that time.

pub fn next_expiration(&mut self, now: u64) -> u64

Dequeues expired timers and returns the next alarm time.